<?php

class root_response {
    public $transaccion;
    public $mensaje;  	
    public $datos;
	public $nid;	
}


class core_usuario {
    public $nid;
	public $nidEmpresa;
    public $nombre;    
    public $paterno;
	public $materno;
	public $usuario;
	public $contrasenia;
	public $rol;
	public $nidCliente;
	public $correo;
	
	public $notiApertura;
	public $notiDesconsolidacion;
	public $notiRevision;
	public $notiConsolidacion;
	public $notiCierre;
}

class core_cliente_personal {
    public $nid;
    public $nombre;    
}

class core_aduana_personal {
    public $nid;
    public $nombre;    
}

class core_UNM {
    public $nid;
    public $nombre;    
}

class core_danos_contenedor {
    public $nid;
    public $nombre;    
}

class core_moversa_personal {
    public $nid;
    public $nombre; 
	public $credencial; 
}


class core_cliente {
    public $nid;
    public $nombre;    
    public $patente;
}

class core_cliente_tarifas {
    public $nid;
	public $nidTipoCarga;
    public $tipoCarga;
	public $nidTipoServicio;
    public $tipoServicio; 	
    public $nidImo;
    public $imo;
	public $nidTipoPeso;
	public $tipoPeso;
	public $costo; 
}

class core_materiales {
    public $nid;
    public $nombre;    
    public $nidUNM;
	public $UNM;
	public $costo;
	public $nidClaveSat;
}


class core_servicio{
	public $nid;
	public $nidEmpresa;
	public $codigo;
	public $importador;
	public $nidCliente;
	public $cliente;
	public $personalCliente;
	public $patente;
	public $fiscal;
	public $tipoCarga;
	public $imo;
	public $dimencion;
	public $contenedor;
	public $selloOriginal;
	public $selloNuevo;
	public $cantidad;
	public $peso;
	public $tipoServicio;
	public $cantidadDesconsolidar;
	public $notasCantidad;
	public $utilizaCanino;
	public $notasCarga;
	public $revisionIntrusiva;
	public $muestreo;
	public $observacionesMuestreo;
	public $obsDesconsol;
	public $clienteFacturar;
	public $montoServicio;
	public $montoMaterial;
	public $montoTotal;
	public $fechaRegistro;
	public $estado;
	public $pedimento;
	public $referencia;
	public $nidFactura;
	public $uuid;
}

class core_servicio_pedimentos {
    public $nid;
    public $pedimento;    
    public $referencia;
}

class core_servicio_materiales {
    public $nid;
    public $material;    
    public $cantidad;
	public $unm;
}

class core_servicio_personal {
    public $nid;
    public $nombre;
}

class core_servicio_bitacora {
    public $nid;
    public $descripcion;
	public $fecha;
}

class core_correos {
    public $cuenta;
}

class core_servicio_EIR {
    public $nid;
    public $nidLado;
	public $estado;
}

class core_FechaHora_BD{
    public $fechaHora;
}

class core_cliente_material {
    public $nid;
    public $material;
	public $unidad;
	public $costo;
}


class core_forma_pago {
    public $nid;
    public $clave;    
    public $descripcion;
}

class core_uso_cfdi {
    public $nid;
    public $clave;    
    public $descripcion;
}

class core_metodo_pago {
    public $nid;
    public $clave;    
    public $descripcion;
}

class core_clave_sat {
    public $nid;
    public $clave;    
    public $descripcion;
}

class core_paises {
    public $nid;
    public $nombre;
}